#!/usr/bin/env python

"""
This module is part of the file integrity checker 'Spot The Difference'.
It subcalasses the generic class 'IntegrityChecker' to make it interact with
PostgreSQL databases.
It only overrides the 'open_db' method.
"""


import psycopg
from spot import IntegrityChecker
import os
from sys import exit


class spot(IntegrityChecker):

    """File integrity checker with PostgreSQL database access"""

    def __init__(self, options, paths, vars_):
        """Call the parent __init__ method"""
        IntegrityChecker.__init__(self, options, paths, vars_)

    def open_db(self):
        """Connect to the database

        The parameters in the configuration file are used to connect to the
        database. The database object and the table name are returned. The
        'db_name' attribute is set to a string in the form:

          <db>.<table> on <host>

        as requested by the superclass.
        """
        kwargs = {}

        conn_params = ("user", "password", "host", "port", "database")
        cfg_params  = ("user", "passwd", "host", "port", "db")
        for k1, k2 in zip(conn_params, cfg_params):
            try:
                kwargs[k1] = self.vars[k2]
            except:
                if not (k2 == "port" and os.path.isdir(self.vars["host"])):
                    exit("Variable '%s' not set in file '%s'" %
                         (k2, self.options.cfg_file))

        try:
            table = self.vars["table"]
        except KeyError:
            exit("Variable 'table' not set in file '%s'" %
                 self.options.cfg_file)

        self.db_name = "%s.%s on %s" % (kwargs["database"], table, kwargs["host"])

        # Connect and select database
        kwargs["serialize"] = 1
        try:
            db = apply(psycopg.connect, (), kwargs)
        except:
            exit("Could not connect to server '%s'" % kwargs["host"])
        else:
            db.autocommit()
            return (db, table)

